@@ -1,9 +1,9 @@
 # SystemC - SystemC Perl Interface
-# $Id: Netlist.pm 43371 2007-08-16 14:00:54Z wsnyder $
+# $Id: Netlist.pm 49154 2008-01-02 14:22:02Z wsnyder $
 # Author: Wilson Snyder <wsnyder@wsnyder.org>
 ######################################################################
 #
-# Copyright 2001-2007 by Wilson Snyder.  This program is free software;
+# Copyright 2001-2008 by Wilson Snyder.  This program is free software;
 # you can redistribute it and/or modify it under the terms of either the GNU
 # General Public License or the Perl Artistic License.
 # 
@@ -27,7 +27,7 @@ use Verilog::Netlist::Subclass;
 use strict;
 use vars qw($Debug $Verbose $VERSION);
 
-$VERSION = '1.281';
+$VERSION = '1.282';
 
 ######################################################################
 #### Error Handling
@@ -218,6 +218,21 @@ sub new_file {
 }
 
 sub read_file {
+    my $self = shift;
+    my %params = (netlist=>$self,
+		 @_);
+
+    if ($params{filename}) {
+	my $filepath = $self->resolve_filename($params{filename});
+	if (($filepath||'') =~ /\.v$/) {
+	    return $self->read_verilog_file(is_libcell=>1,
+					    %params);
+	}
+    }
+    return $self->read_sp_file(%params);
+}
+
+sub read_sp_file {
     my $self = shift;
     my $fileref = SystemC::Netlist::File::read
 	(netlist=>$self,
@@ -358,7 +373,7 @@ SystemPerl is part of the L<http://www.veripool.com/> free SystemC software
 tool suite.  The latest version is available from CPAN and from
 L<http://www.veripool.com/systemperl.html>.
 
-Copyright 2001-2007 by Wilson Snyder.  This package is free software; you
+Copyright 2001-2008 by Wilson Snyder.  This package is free software; you
 can redistribute it and/or modify it under the terms of either the GNU
 Lesser General Public License or the Perl Artistic License.
 
