@@ -1,9 +1,9 @@
 # SystemC - SystemC Perl Interface
-# $Id: File.pm 43371 2007-08-16 14:00:54Z wsnyder $
+# $Id: File.pm 49154 2008-01-02 14:22:02Z wsnyder $
 # Author: Wilson Snyder <wsnyder@wsnyder.org>
 ######################################################################
 #
-# Copyright 2001-2007 by Wilson Snyder.  This program is free software;
+# Copyright 2001-2008 by Wilson Snyder.  This program is free software;
 # you can redistribute it and/or modify it under the terms of either the GNU
 # General Public License or the Perl Artistic License.
 # 
@@ -23,7 +23,7 @@ use SystemC::Template;
 use Verilog::Netlist::Subclass;
 @ISA = qw(SystemC::Netlist::File::Struct
 	Verilog::Netlist::Subclass);
-$VERSION = '1.281';
+$VERSION = '1.282';
 use strict;
 
 structs('new',
@@ -318,6 +318,15 @@ sub auto {
 			   \&SystemC::Netlist::Module::_write_autoinout,
 			   $modref, $self->{fileref}, $1]);
     }
+    elsif ($line =~ /^(\s*)\/\*AUTOTIEOFF\*\//) {
+	if (!$modref) {
+	    return $self->error ("AUTOTIEOFF outside of module definition", $line);
+	}
+	$modref->attributes("autotieoff",1);
+	push_text($self, [ 1, $self->filename, $self->lineno,
+			   \&SystemC::Netlist::Module::_write_autotieoff,
+			   $modref, $self->{fileref}, $1]);
+    }
     elsif ($line    =~ /^(\s*)SP_AUTO_COVER	  # $1 prefix
 	   		 (?:  inc \s* \( \s* \d+, # SP_AUTO_COVERinc(id, 
 			  |   \d* \s* \( )	  # SP_AUTO_COVER1(
@@ -1399,7 +1408,7 @@ SystemPerl is part of the L<http://www.veripool.com/> free SystemC software
 tool suite.  The latest version is available from CPAN and from
 L<http://www.veripool.com/systemperl.html>.
 
-Copyright 2001-2007 by Wilson Snyder.  This package is free software; you
+Copyright 2001-2008 by Wilson Snyder.  This package is free software; you
 can redistribute it and/or modify it under the terms of either the GNU
 Lesser General Public License or the Perl Artistic License.
 
